@@ -35,7 +35,7 @@ def get_root_dir() -> pathlib.Path:
 ROOT_DIR = get_root_dir()
 LOG_DATA_DIR = ROOT_DIR / ".logs"
 LOG_DATA_DIR.mkdir(exist_ok=True)
-DATETIME_FORMAT = "%Y-%m-%d %H:%M:%S"
+DATETIME_FORMAT = "iso"
 _CONFIGS = {"USE_ORJSON": True}
 
 
@@ -65,11 +65,11 @@ def deduce_module(prev_stack_frame: inspect.FrameInfo) -> Optional[ModuleType]:
 
 
 def get_caller_name_from_frames(stack_frames: List[inspect.FrameInfo]) -> str:
-    prev_stack_frame = stack_frames[0]
+    prev_stack_frame = stack_frames[1] if __file__.endswith(".py") else stack_frames[0]
     return get_caller_name(prev_stack_frame)
 
 
-def get_logger() -> Any:
+def get_logger(name: Optional[str] = None) -> Any:
     """
     Convenience function that returns a logger
 
@@ -77,13 +77,16 @@ def get_logger() -> Any:
     the __name__ of the calling module
 
     """
+    del name
     stack_frames = inspect.stack()
     caller_name = get_caller_name_from_frames(stack_frames)
     if not structlog.is_configured():
         timestamper = structlog.processors.TimeStamper(fmt=DATETIME_FORMAT)
         set_logging_config(caller_name, timestamper)
         set_structlog_config(timestamper)
-    return structlog.get_logger(caller_name)
+    logger = structlog.get_logger(caller_name)
+    logger.setLevel(logging.DEBUG)
+    return logger
 
 
 getLogger = get_logger
@@ -121,7 +124,11 @@ def get_logging_config(
         "formatters": (get_formatters(timestamper)),
         "handlers": handlers,
         "loggers": {
-            "": {"handlers": list(handlers.keys()), "level": "DEBUG", "propagate": True}
+            "": {
+                "handlers": list(handlers.keys()),
+                "level": "WARNING",
+                "propagate": True,
+            }
         },
     }
 
@@ -181,8 +188,8 @@ def get_handlers(module_name: str) -> dict:
         # Prettify stdout/stderr streams
         base_handlers[default_key]["formatter"] = "colored"
         # Add filename handler
-        file_timestamp = datetime.datetime.utcnow().strftime("%Y-%m-%d")
-        log_file_name = f"{file_timestamp}_{module_name}.json"
+        file_timestamp = datetime.datetime.utcnow().isoformat().replace(":", "-")
+        log_file_name = f"{file_timestamp}_{module_name}.jsonl"
         log_file_path = LOG_DATA_DIR / log_file_name
         base_handlers["filename"] = {
             "level": "DEBUG",
@@ -206,6 +213,7 @@ def set_structlog_config(timestamper: structlog.processors.TimeStamper) -> None:
         add_severity_field_from_level_if_in_cloud_environment,
     ]
     stdlib_log_compatibility_processors = [
+        structlog.stdlib.filter_by_level,
         structlog.stdlib.add_log_level,
         structlog.stdlib.add_logger_name,
         structlog.stdlib.PositionalArgumentsFormatter(),
